@@ -1,11 +1,12 @@
 package SDL::TestTool;
 use strict;
 use warnings;
-use Capture::Tiny qw(capture);
-use SDL;
+use IO::CaptureOutput qw(capture);
+use SDL qw(:all);
 use SDL::AudioSpec;
 use SDL::Audio;
-my %inits = (
+my %inits =
+(
 	0x00000001 => 'SDL_INIT_TIMER',
 	0x00000010 => 'SDL_INIT_AUDIO',
 	0x00000020 => 'SDL_INIT_VIDEO',
@@ -17,34 +18,40 @@ my %inits = (
 );
 
 sub init {
-	my ( $self, $init ) = @_;
-	my $stdout = '';
-	my $stderr = '';
+    my ($self, $init) = @_; 
+    my $stdout = '';
+    my $stderr = '';
 
-	if ( $init == SDL_INIT_VIDEO ) {
-		if ( $^O !~ /win/i && !$ENV{DISPLAY} && !$ENV{SDL_VIDEODRIVER} ) {
-			warn '$DISPLAY is not set! Cannot Init Video';
-			return;
-		}
-	}
+    if( $init == SDL_INIT_VIDEO)
+    {
+	    if( $^O !~ /win/i && !$ENV{DISPLAY} && !$ENV{SDL_VIDEODRIVER})
+	    {
+		    warn '$DISPLAY is not set! Cannot Init Video';
+		    return ;
+	    }
+    }
 
-	if ( $init == SDL_INIT_AUDIO ) {
-		if ( test_audio_open() != 0 ) {
+	if( $init == SDL_INIT_AUDIO)
+	{
+		if (test_audio_open() != 0) 
+		{
 			warn "Couldn't use a valid audio device: " . SDL::get_error();
-			return;
+			return ;
 		}
 		SDL::quit();
 	}
 
-	( $stdout, $stderr ) = capture { SDL::init($init) };
-	if ( $stderr ne '' ) {
-		warn 'Init ' . $inits{$init} . ' failed with SDL error: ' . SDL::get_error() . "\nand stderr $stderr\n";
-	}
-
-	return !( $stderr ne '' );
+    capture { SDL::init($init) } \$stdout, \$stderr;
+    if ( $stderr ne '' )
+    {
+	    warn 'Init '.$inits{$init}.' failed with SDL error: '. SDL::get_error()."\nand stderr $stderr\n";
+    }
+    
+    return !($stderr ne '');
 }
 
-sub test_audio_open {
+sub test_audio_open
+{
 	my $desired = SDL::AudioSpec->new;
 	$desired->freq(44100);
 	$desired->format(SDL::Audio::AUDIO_S16SYS);
@@ -53,10 +60,11 @@ sub test_audio_open {
 	$desired->callback('main::audio_callback');
 
 	my $obtained = SDL::AudioSpec->new;
-	return SDL::Audio::open( $desired, $obtained );
+	return  SDL::Audio::open( $desired, $obtained );
 }
 
-sub audio_callback {
+sub audio_callback
+{
 
 }
 
